==> service-common-2.24.0-20170428.014318-47-sources.jar: com/baijia/tianxiao/util/SmsSendUtil.java <==
/**
 * Baijiahulian.com Inc. Copyright (c) 2014-2015 All Rights Reserved.
 */
package com.baijia.tianxiao.util;

import com.baijia.tianxiao.constants.SmsGateGroup;
import com.baijia.tianxiao.dto.RestfulResult;
import com.baijia.tianxiao.util.http.GSXService;
import com.baijia.tianxiao.validation.ParamValidateUtils;
import com.google.common.base.Preconditions;
import lombok.extern.slf4j.Slf4j;

import java.util.SortedMap;
import java.util.TreeMap;

/**
 * @author cxm
 * @version 1.0
 * @title SmsSendUtil
 * @desc TODO
 * @date 2015年10月26日
 */
@Slf4j
public class SmsSendUtil {

    public static final String ORG_BANK_UNBIND_CARD =
            "尊敬的{shortName},您已成功从跟谁学账户解绑尾号为{cardNo}的银行卡，请知悉，如有疑问，请及时拨打4000-910-910";

    public static final String ORG_BANK_BIND_CARD =
            "尊敬的{shortName}机构,您的跟谁学账户成功绑定了尾号为{cardNo}的银行卡，请知悉，如有疑问，请及时拨打4000-910-910";

    //public static final List<Integer> smsList = Arrays.asList(48966, 68383, 56822, 64508, 69063, 69065, 69066);//不发送短信的机构黑名单

    public static boolean sendSms(String mobile, String content, Integer messageType, Integer userId, Integer userRole,
                                  boolean directSend, Integer smsGate) {

        //封禁短信在yunying.tx_account.sms_gate=-1里配置
        if (smsGate != null && smsGate.intValue() == -1) {
            return false;
        }

        RestfulResult<Object> response = send(mobile, content, messageType, userId, userRole, directSend, smsGate);
        return response != null && response.getCode() == 0;
    }

    public static RestfulResult<Object> send(String mobile, String content, Integer messageType, Integer userId,
                                             Integer userRole, boolean directSend, Integer smsGate) {
        RestfulResult<Object> response = null;
        try {
            String controller = "sms";
            String action = "send";
            SortedMap<String, String> params = new TreeMap<String, String>();
            params.put("mobile", mobile.replaceAll(" ", "").replace("-", ""));
            Preconditions.checkArgument(ParamValidateUtils.validateMobile(params.get("mobile")),
                    "mobile :" + mobile + " is invalidate.");

            params.put("content", content);
            params.put("message_type", String.valueOf(messageType));
            if (userId != null) {
                params.put("user_id", String.valueOf(userId));
            }
            if (userRole != null) {
                params.put("role", String.valueOf(userRole));
            }
            if (directSend) {
                params.put("direct_send", "1");
            }
            if (smsGate != null) {
                params.put("gateway", smsGate.toString());
            } else {
                params.put("gateway", SmsGateGroup.DEFAULT_SMS_GATE.toString());
            }

            log.info("send sms to mobile:{},params:{}", mobile, params);
            response = GSXService.doService(controller, action, params);
            log.info("params:{}, response:{}", params, response);
        } catch (Exception e) {
            response = new RestfulResult<>();
            response.setCode(1);
            response.setData(null);
            response.setMsg("发送短信失败");
            log.error("sendSms exception - ", e);
        }
        return response;
    }

    public static boolean sendSms(String mobile, String content, Integer messageType, Integer userId, Integer userRole,
                                  Integer smsGate) {
        //封禁短信在yunying.tx_account.sms_gate=-1里配置
        if (smsGate != null && smsGate.intValue() == -1) {
            return false;
        }
        return sendSms(mobile, content, messageType, userId, userRole, true, smsGate);
    }


    public static void main(String[] args) {
        Integer userId = 489661;
        //System.out.println(smsList.contains(userId == null ? 0 : userId.intValue()));
    }

}

==> service-common-2.41.0-20170921.040332-70-sources.jar: com/baijia/tianxiao/util/SmsSendUtil.java <==
package com.baijia.tianxiao.util;

import com.baijia.tianxiao.constants.sms.SmsMessageType;
import com.baijia.tianxiao.dto.RestfulResult;
import com.baijia.tianxiao.util.http.GSXService;
import com.baijia.tianxiao.validation.ParamValidateUtils;
import com.google.common.base.Preconditions;
import lombok.extern.slf4j.Slf4j;

import java.util.SortedMap;
import java.util.TreeMap;

/**
 * @author cxm
 * @version 1.0
 * @title SmsSendUtil
 * @desc TODO
 * @date 2015年10月26日
 */
@Slf4j
public class SmsSendUtil {

    public static final String GSX_SMS_CONTROLLER = "sms";//跟谁学服务接口
    public static final String GSX_SMS_ACTION = "send";//跟谁学服务接口
    public static Integer DEFAULT_SMS_GATE = 6;//天校后缀短信发送默认网关6

    public static boolean sendTxSms(String mobile, String content, Integer userId, Integer userRole, Integer smsGate) {
        //封禁短信在yunying.tx_account.sms_gate=-1里配置
        if (smsGate != null && smsGate.intValue() == -1) {
            return false;
        }

        RestfulResult<Object> response = send(mobile, content, SmsMessageType.TIANXIAO_NOTIFY.getCode(), userId, userRole, true, smsGate);
        return response != null && response.getCode() == 0;
    }

    public static RestfulResult<Object> send(String mobile, String content, Integer messageType, Integer userId,
                                             Integer userRole, boolean directSend, Integer smsGate) {
        RestfulResult<Object> response = null;

        //封禁短信在yunying.tx_account.sms_gate=-1里配置
        if (smsGate != null && smsGate.intValue() == -1) {
            return RestfulResult.buildError("发送短信功能被禁用");
        }
        try {
            SortedMap<String, String> params = new TreeMap<String, String>();
            params.put("mobile", mobile.replaceAll(" ", "").replace("-", ""));
            Preconditions.checkArgument(ParamValidateUtils.validateMobile(params.get("mobile")),
                    "mobile :" + mobile + " is invalidate.");

            params.put("content", content);
            params.put("message_type", String.valueOf(messageType));
            if (userId != null) {
                params.put("user_id", String.valueOf(userId));
            }
            if (userRole != null) {
                params.put("role", String.valueOf(userRole));
            }
            if (directSend) {
                params.put("direct_send", "1");
            }
            if (smsGate != null) {
                params.put("gateway", smsGate.toString());
            } else {
                params.put("gateway", String.valueOf(DEFAULT_SMS_GATE));
            }

            log.info("send sms to mobile:{},params:{}", mobile, params);
            response = GSXService.doService(GSX_SMS_CONTROLLER, GSX_SMS_ACTION, params);
            log.info("params:{}, response:{}", params, response);
        } catch (Exception e) {
            response = RestfulResult.buildError("发送短信失败");
            log.error("sendSms exception - ", e);
        }
        return response;
    }

    public static void main(String[] args) {
        Integer userId = 489661;
        // System.out.println(smsList.contains(userId == null ? 0 : userId.intValue()));
    }

}
